@@ -71,6 +71,16 @@ def GetSensorData():
 
 
 
+def GetFirstEntry():
+    records.arrData[0][0]=strftime("%H:%M:%S", time.localtime())
+    records.arrData[1][0]=0
+    records.arrData[2][0]=0
+    
+    records.Index=1
+    records.LastIndex=max(records.Index,  records.LastIndex)
+        
+        
+
 
 ###########################################################################
 ##  Process the data, generate movement indication
@@ -80,6 +90,7 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
     if(ProcessAll==True): start=0 #process whole array
     else: start=records.Index-data.Derivation-1 #process only last (changed) records
     
+    lastindexovertrigger=records.arrData[4][start]
     for i in range(start, records.Index-data.Derivation):     
         t=i*(records.Sampling_interval*records.Value_smoothing)/1000
         if(data.QuickMode==True or t>data.DelayStartTime):
@@ -90,7 +101,12 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
             Xder=0
             Yder=0
             XYder=0
-        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higer than graph border
+        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
+        records.arrData[4][i]=lastindexovertrigger
+#        if(records.arrData[3][i]>data.Trigger): #over trigger
+#            lastindexovertrigger=i
+        
+            
 
 #    for i in range(max(start,  5), records.Index-data.Derivation):     
 #        t=i*(records.Sampling_interval*records.Value_smoothing)/1000
@@ -102,7 +118,7 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 #            Xder=0
 #            Yder=0
 #            XYder=0
-#        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higer than graph border
+#        records.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
 
 
 
@@ -119,12 +135,12 @@ def showGraph(self,  QtGui):
         if(data.debug==1): print "------>         Do not redraw, nothing changed!"
         return 
         
+    print data.logfilename
+#    print "----------------------------"
     ScrollbarStartPercent, ScrollbarEndPercent=ScrollbarData()
     Xscale=data.arrXscale[data.Xscale]
-   
-#    pixelshift=data.Derivation*records.Sampling_interval*records.Value_smoothing/1000/Xscale/10-1
-    pixelshift=0
-    
+    decade=360/Xscale
+
 #        print "-----------------------------------"
 #        print "Xscale:",  Xscale
 #        print "Current index:",  records.Index
@@ -138,6 +154,8 @@ def showGraph(self,  QtGui):
 #        print "Shown graph is from index",  data.GraphStart,  "to",  data.GraphStart+GraphLen
         
 #    PrintRecordData()
+
+    print "data.QuickMode:",  data.QuickMode
         
     data.ChangesInGraph=False
     paint = QtGui.QPainter()
@@ -158,43 +176,70 @@ def showGraph(self,  QtGui):
         return
     
     
-#    print "data.GraphStart",  data.GraphStart
-    h0=int(strftime("%H", Index2Tuple(data.GraphStart)))
-    m0=int(strftime("%M", Index2Tuple(data.GraphStart)))
-    s0=int(strftime("%M", Index2Tuple(data.GraphStart)))
-            
-    #decade (scaling):
-    #6 => 60px/h
-    #1 => 360px/h
-    decade=360/Xscale
-    secondstonexthour=3600-(m0*60+s0)
-    offset=secondstonexthour*decade/3600
-#    print secondstonexthour,  "---",  offset,  data.Derivation*records.Sampling_interval*records.Value_smoothing/1000
-#    x=secondstonexthour-data.Derivation*records.Sampling_interval*records.Value_smoothing/1000
-#    offset=x*decade/3600
-#    print secondstonexthour,  x,  offset
+    GraphStart_tuple=Index2Tuple(data.GraphStart)
+    print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
+    h=int(strftime("%H", GraphStart_tuple))
+    m=int(strftime("%M", GraphStart_tuple))
+    s=int(strftime("%S", GraphStart_tuple))
+    print h,  m,  s
+    
+    secondsincefullhour=m*60+s
+    GraphStart_seconds=Tuple2Seconds(GraphStart_tuple)
+    LastFullHour_sec=GraphStart_seconds-secondsincefullhour
+    LastFullHour_tuple=Seconds2Tuple(LastFullHour_sec)
+    
+    h0=int(strftime("%H", LastFullHour_tuple))
+    m0=int(strftime("%M", LastFullHour_tuple))
+    s0=int(strftime("%S", LastFullHour_tuple))
+    print h0,  m0,  s0
+    
+    
+    print GraphStart_seconds,  LastFullHour_sec,  secondsincefullhour
+    print GraphStart_tuple,  LastFullHour_tuple
+    
+    LastFullHour_index=Tuple2Index(LastFullHour_tuple)
 
+    GraphStart_index=Tuple2Index(GraphStart_tuple) #should be same as data.GraphStart, but is not due rounding
+    print "Indexes:",  GraphStart_index,  "(",  data.GraphStart, ")",  LastFullHour_index
+    
+    OffsetToLastFullHour=-1*(GraphStart_index-LastFullHour_index)/Xscale 
+    OffsetToLastFullHour=OffsetToLastFullHour-data.Derivation #Derivation takes 5 idnices, so visualisation is delayed!
     
     #DRAW main scaling lines + text        
-    paint.setPen(QtGui.QColor("yellow"))
+    paint.setPen(QtGui.QColor("white"))
     if(data.QuickMode==False): #normal mode
-        for i in range(-1*decade, 781+decade,  decade):
-            paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
-            for k in range(1, 6):
-                x=i+offset+k*decade/6-decade
-                paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
-            h=(h0+int(i/decade)+1) % 24
-            if(data.Xscale==0):#add bigger main hours on biggest zoom level
+        print "OffsetToLastFullHour:",  OffsetToLastFullHour
+        if(data.Xscale==0): #max zoom
+            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
+                h=(h0+int(i/decade)+1) % 24
+#                print i
+                paint.drawLine(i, data.Ysize, i, data.Ysize+10) 
                 paint.setFont(QtGui.QFont('Decorative', 18))
-                paint.drawText(i+offset-15, data.Ysize+32, str(h)) 
+                paint.drawText(i-15, data.Ysize+30, str(h))
                 paint.setFont(QtGui.QFont('Decorative', 12))
-            else:
-                paint.drawText(i+offset-15, data.Ysize+30, str(h)+":00")                
-            if(data.Xscale==0): #add extra marks/numbers on biggest zoom level
-                for k in range(1, 6):  paint.drawText(i+offset-15+k*decade/6, data.Ysize+23, str(h)+":"+str(10*k))
-                for k in range(1, 12): paint.drawLine(x+decade/12*k, data.Ysize, x+decade/12*k, data.Ysize+5)
-    else: #test mode, do not show X scale as it is not calibrated
-        paint.drawText(200, data.Ysize+20, "Test Mode")
+                for k in range(1, 6): #hour + k * 10 minutes
+                    x=i+k*decade/6
+#                    print " ", x,  str(h)+":"+str(10*k)
+                    paint.drawLine(x, data.Ysize, x, data.Ysize+10)  
+                    paint.drawText(x-20, data.Ysize+26, str(h)+":"+str(10*k))
+                for m in range(1, 30): #hour + m * 2 minutes
+                    x2=i+m*decade/30
+#                    print "  ",  x2
+                    paint.drawLine(x2, data.Ysize, x2, data.Ysize+4) 
+
+        elif(data.Xscale==1 or data.Xscale==2): #mid + min zoom
+            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
+                h=(h0+int(i/decade)+1) % 24
+#                print i
+                paint.drawLine(i, data.Ysize, i, data.Ysize+10) 
+                paint.drawText(i-15, data.Ysize+30, str(h)+":00")
+                for k in range(1, 6): #hour + k * 10 minutes
+                    x=i+k*decade/6
+#                    print " ", x,  str(h)+":"+str(10*k)
+                    paint.drawLine(x, data.Ysize, x, data.Ysize+4)  
+
+    else: #quick mode, do not show X scale as it is not calibrated
+        paint.drawText(200, data.Ysize+20, "Test Mode, no scale available")
     
 
     
@@ -212,80 +257,125 @@ def showGraph(self,  QtGui):
         paint.drawRect(x0,  data.Ysize+38, x1-x0 ,  5)
 
 
-    #DRAW graph + time bars
-    paint.setPen(QtGui.QColor("yellow"))        
-    lastmovebeforegraph=0        
-    peak=0
-            
-    #get data for very first time bar
-    for m in range(data.GraphStart,  0,  -1):    #find last peak before shown graph
-        if(records.arrData[3][m]>records.Trigger): 
-            lastmovebeforegraph=m-data.GraphStart
-            break
 
-#    print "corr",  data.Derivation*records.Sampling_interval*records.Value_smoothing/1000/Xscale/10
-    
-    lastdatapoint=records.Index
-    for p in range(data.GraphStart,  records.Index-data.Derivation,  Xscale):
-        i=p-data.GraphStart
+
+    #DRAW time bars
+    start=GraphStart_index % 6
+    lastmoveovertrigger=start
+    for p in range(start,  records.Index-data.Derivation):
+        if(records.arrData[3][p]>data.Trigger or p>records.Index-data.Derivation-2):
+            x0=(lastmoveovertrigger-GraphStart_index)/Xscale
+            x1=(p-GraphStart_index)/Xscale
+#            print lastmoveovertrigger,  p,  "(", x0,  x1 , ")"
+#            if(x1-Xscale<=x0):
+#                print "-"
+#                continue
+            lastmoveovertrigger=p
+
+            if(x0<x1): 
+                t=(x1-x0)*Xscale/6        
+#                print x0,  x1
+                if(t>30): color="#009100" #green
+                elif(t>15): color="#005000" #dark green
+                elif(t>7): color="#97320e" #orange
+                else: color="#6D0000" #dark red                   
+                paint.setBrush(QtGui.QColor(color))
+                paint.setPen(QtGui.QColor(color))
+                paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)                     
+#                paint.setPen(QtGui.QColor("yellow"))
+
+
+
+
+    #DRAW graph
+    paint.setPen(QtGui.QColor("yellow"))           
+    peak=0
+    for p in range(GraphStart_index,  records.Index-data.Derivation,  Xscale):
+        i=p-GraphStart_index
         if(i>779*Xscale): break
         #when Xscale is small, we have to merge several records into 1 pixel.
         #Too not miss any movement, we use the biggest movement of the merged records:
         peak=0            
         for j in range(0, Xscale): 
             if(records.arrData[3][p+j]>peak): peak=records.arrData[3][p+j]
-        x=i/Xscale+pixelshift
+        x=i/Xscale
 #        x=i/Xscale+1
         paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
+        
+        if(peak>data.Trigger):
+            paint.setPen(QtGui.QColor("black"))
+            paint.drawLine(x, data.Ysize-11, x, data.Ysize-1)  #draw yellow movement bar
+            paint.setPen(QtGui.QColor("yellow"))
+
+
+
+
+
+
+
 
         #draw time bars
 #        if(peak>records.Trigger): 
-        if(peak>data.Trigger): 
-            lastdatapoint=p # used for last time bar
-            x0=max(lastmovebeforegraph/Xscale+1, 0)+pixelshift
-            if(x0==1):  x0=0
-            x1=i/Xscale-1+pixelshift
-            if(x0<x1): 
-                    t=(x1-x0)*Xscale/6          
-                    if(t>30): color="#009100" #green
-                    elif(t>15): color="#005000" #dark green
-                    elif(t>7): color="#97320e" #orange
-                    else: color="#6D0000" #dark red                   
-                    paint.setBrush(QtGui.QColor(color))
-                    paint.setPen(QtGui.QColor(color))
-                    paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)                     
-                    paint.setPen(QtGui.QColor("yellow"))
-            lastmovebeforegraph=i
+#        if(peak>data.Trigger): 
+#            x0=max(lastmovebeforegraph/Xscale+1, 0)
+#            if(x0==1):  x0=0
+#            x1=i/Xscale-1
+#            print i,  (x1-x0)*Xscale/6 
+#            if(x0<x1): 
+#                    t=(x1-x0)*Xscale/6          
+#                    if(t>30): color="#009100" #green
+#                    elif(t>15): color="#005000" #dark green
+#                    elif(t>7): color="#97320e" #orange
+#                    else: color="#6D0000" #dark red                   
+#                    paint.setBrush(QtGui.QColor(color))
+#                    paint.setPen(QtGui.QColor(color))
+#                    paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)                     
+#                    paint.setPen(QtGui.QColor("yellow"))
+##            lastdatapoint=p # used for last time bar
+#            lastdatapoint=i # used for last time bar
+#            lastmovebeforegraph=i
+#            
+#            
+            
             
             
     # Draw very last time bar
-    x0=(lastdatapoint-data.GraphStart)/Xscale+1+pixelshift
-    x1=(records.Index-data.GraphStart-data.Derivation)/Xscale+pixelshift
-    if(x0<x1):
-        t=(x1-x0)*Xscale/6          
-        if(t>30): color="#009100" #green
-        elif(t>15): color="#005000" #dark green
-        elif(t>7): color="#97320e" #orange
-        else: color="#6D0000" #dark red                   
-        paint.setBrush(QtGui.QColor(color))
-        paint.setPen(QtGui.QColor(color))                    
-        x1=min(779, x1)
-        paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)   
+#    firstmoveaftergraph=records.Index
+#    for p in range(lastdatapoint, records.Index):
+#        if(records.arrData[3][p]>data.Trigger): 
+#            firstmoveaftergraph=p-GraphStart_index
+#            break
+#    x1=(firstmoveaftergraph-GraphStart_index)/Xscale
+#    x0=(lastdatapoint-GraphStart_index)/Xscale+1
+#    x1=(records.Index-GraphStart_index-data.Derivation)/Xscale
+#    print x0,  x1,  (x1-x0)*Xscale/6   
+#    if(x0<x1):
+#        t=(x1-x0)*Xscale/6          
+#        if(t>30): color="#009100" #green
+#        elif(t>15): color="#005000" #dark green
+#        elif(t>7): color="#97320e" #orange
+#        else: color="#6D0000" #dark red                   
+#        paint.setBrush(QtGui.QColor(color))
+#        paint.setPen(QtGui.QColor(color))                    
+#        x1=min(779, x1)
+#        paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)   
         
         
-    #check if at least one grapth is drawn
-    if(lastmovebeforegraph==0): #no interuption in whole graph
-        x0=0+pixelshift
-        x1=(records.Index-data.GraphStart-data.Derivation)/Xscale+pixelshift
-        if(x0<x1):
-            t=(x1-x0)*Xscale/6          
-            if(t>30): color="#009100" #green
-            elif(t>15): color="#005000" #dark green
-            elif(t>7): color="#97320e" #orange
-            else: color="#6D0000" #dark red                  
-            paint.setBrush(QtGui.QColor(color))
-            paint.setPen(QtGui.QColor(color))                    
-            paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)   
+        
+        
+    #check if at least one time bar is drawn
+#    if(lastmovebeforegraph==0): #no interuption in whole graph
+#        x0=0
+#        x1=(records.Index-GraphStart_index-data.Derivation)/Xscale
+#        if(x0<x1):
+#            t=(x1-x0)*Xscale/6          
+#            if(t>30): color="#009100" #green
+#            elif(t>15): color="#005000" #dark green
+#            elif(t>7): color="#97320e" #orange
+#            else: color="#6D0000" #dark red                  
+#            paint.setBrush(QtGui.QColor(color))
+#            paint.setPen(QtGui.QColor(color))                    
+#            paint.drawRect(x0+1, data.Ysize-11, x1-x0-1, 10)   
         
         
         
@@ -294,29 +384,28 @@ def showGraph(self,  QtGui):
     if(records.AlarmIsSet==True): #alarm time window is set, show it            
         paint.setBrush(QtGui.QColor("Orange"))
         paint.setPen(QtGui.QColor("Orange"))  
-        x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)
-        x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)
-#        x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation+Xscale
-#        x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation+Xscale
-        x00=(x0-data.GraphStart)/Xscale
-        x10=(x1-data.GraphStart)/Xscale
+        x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
+        x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation*Xscale
+        x00=(x0-GraphStart_index)/Xscale
+        x10=(x1-GraphStart_index)/Xscale
 #        if(x00>0 or x10<780): #visible in screen
 #            x00=max(x00,  1) #limit drawn line to border
 #            x10=min(x10,  780) #limit drawn line to border
 #            if(x00<x10): 
 #        print  x1,   x10
-#        print Tuple2Index((2010, 8, 15, 20, 0, 0, 6, 227, 0)),  (Tuple2Index((2010, 8, 15, 20, 0, 0, 6, 227, 0)) -data.GraphStart)/Xscale
+#        print Tuple2Index((2010, 8, 15, 20, 0, 0, 6, 227, 0)),  (Tuple2Index((2010, 8, 15, 20, 0, 0, 6, 227, 0)) -GraphStart_index)/Xscale
 #        print ""
         paint.drawRect(x00,  8,  x10-x00,  2) #Time Window 
-#            x11=(x1+3-data.GraphStart)/Xscale
+#            x11=(x1+3-GraphStart_index)/Xscale
 #            if(x11>1 and x11<779):        
         paint.drawRect(x10,  4,  1,  10)  #Last Alarm opportunity
                 
         if(data.AlarmIsActive==True or data.run==0): #only show alarm if alarm occured or in record
             paint.setBrush(QtGui.QColor("Red"))
             paint.setPen(QtGui.QColor("Red"))  
-            a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation-3+Xscale
-            a00=(a0-data.GraphStart)/Xscale
+#            a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation-3+Xscale
+            a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
+            a00=(a0-GraphStart_index)/Xscale
             paint.drawEllipse(a00-5, 15, 10, 10)     
 
 
