@@ -212,6 +212,9 @@ def InitMeasurement():
     else: app.timer_GetData.start(1)    #run very fast for testing
     
     CreateRecordFile(data.interval)
+    GetFirstEntry()
+    WriteIntoRecordFile()
+#    WriteFirstEntryIntoRecordFile() #write first entry
    
     data.ChangesInGraph=True #Make sure it only gets refreshed once    
     RecordWindowGraph.update() #show RecordWindowGraph        
@@ -253,6 +256,7 @@ def StopMeasurement():
 
 
 
+
 ############################################################################
 ## Stretch graph to show more details
 ############################################################################
@@ -365,7 +369,7 @@ class frmStartWindow(QMainWindow):
     # Show the log window (where the data from a file gets visualised)
     ###########################################################################
     def ShowViewWindow(self):
-        global ViewWindowGraph        
+        global ViewWindowGraph       
         
         #reset to default log folder
         if(data.demo==True): data.logfolder=data.devlogfolder #folder on devel PC
@@ -596,6 +600,7 @@ class frmRecordWindow(QMainWindow):
         else: #quick mode, delete file anyway and close
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
+            data.QuickMode=False
             StartWindow.show()
             self.hide()
             
@@ -682,7 +687,7 @@ class frmViewWindow(QMainWindow):
             
         diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
         diff_tuple=Seconds2Tuple(diff_sec)
-        diff=strftime("%H:%M:%S", EndTime_tuple)
+        diff=strftime("%H:%M:%S", diff_tuple)
         if(diff_sec>86400): d="1 day, " #longer than 24h
         else: d=""
         self.ui.lblTimes.setText(str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
@@ -809,16 +814,18 @@ class frmViewWindow(QMainWindow):
         
         
     def goLeft(self):
-        data.GraphStart=max(data.GraphStart-600, 0)
+        m=600 #data.arrXscale[data.Xscale]*60
+        data.GraphStart=max(data.GraphStart-m, 0)
         data.ChangesInGraph=True #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
         
         
     def goRight(self):
+        m=600   #data.arrXscale[data.Xscale]*60
         print "records.LastIndex:",  records.LastIndex, data.arrXscale[data.Xscale]*775
         MaxGraphStart=max(records.LastIndex-data.arrXscale[data.Xscale]*775, 0)
-        data.GraphStart=min(MaxGraphStart,  data.GraphStart+600)
+        data.GraphStart=min(MaxGraphStart,  data.GraphStart+m)
         print "goRight MaxGraphStart:",  MaxGraphStart
         print "GraphStart:",  data.GraphStart
 
@@ -1251,7 +1258,7 @@ class frmAskForKeepWindow(QMainWindow):
 class RecordWindowCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 180, 784, data.Ysize+55)
+        self.setGeometry(9, 180, 782, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
@@ -1265,7 +1272,7 @@ class RecordWindowCanvas(QtGui.QWidget):
 class ViewWindowCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 100, 784, data.Ysize+55)
+        self.setGeometry(9, 100, 782, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
